@@ -58,7 +58,7 @@ enum
 	KB_COUNT
 };
 
-GtkWidget *create_Interactive(void);
+GtkWidget *create_Interactive(const gchar * default_word);
 
 static gboolean word_check_left(gchar c)
 {
@@ -221,11 +221,12 @@ kb_doc(G_GNUC_UNUSED guint key_id)
 static void
 kb_doc_ask(G_GNUC_UNUSED guint key_id)
 {
-	gchar *word = NULL;
+	gchar *word = NULL, *default_word = current_word();
 	GtkWidget *dialog, *entry;
 
 	/* example configuration dialog */
-	dialog = create_Interactive();
+	dialog = create_Interactive(default_word);
+	g_free(default_word);
 
 	/* run the dialog and check for the response code */
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
@@ -256,7 +257,7 @@ on_comboboxType_changed(GtkComboBox * combobox, G_GNUC_UNUSED gpointer user_data
 	GKeyFile *config = (GKeyFile *) g_object_get_data(G_OBJECT(combobox), "config");
 
 	from = g_object_get_data(G_OBJECT(combobox), "current");
-	to = gtk_combo_box_get_active_text(combobox);
+	to = gtk_combo_box_text_get_active_text(combobox);
 
 	if (from != NULL)
 	{
@@ -284,13 +285,13 @@ on_comboboxType_changed(GtkComboBox * combobox, G_GNUC_UNUSED gpointer user_data
 
 #define GLADE_HOOKUP_OBJECT(component,widget,name) \
   g_object_set_data_full (G_OBJECT (component), name, \
-    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
+    g_object_ref (widget), (GDestroyNotify) g_object_unref)
 
 #define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
   g_object_set_data (G_OBJECT (component), name, widget)
 
 GtkWidget *
-create_Interactive(void)
+create_Interactive(const gchar * default_word)
 {
 	GtkWidget *dialog_vbox1;
 	GtkWidget *entry_word;
@@ -303,9 +304,11 @@ create_Interactive(void)
 							GTK_STOCK_CANCEL,
 							GTK_RESPONSE_REJECT,
 							NULL);
-	dialog_vbox1 = GTK_DIALOG(dialog)->vbox;
+	dialog_vbox1 = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
 	entry_word = gtk_entry_new();
+	if (default_word)
+		gtk_entry_set_text(GTK_ENTRY(entry_word), default_word);
 	gtk_widget_show(entry_word);
 	gtk_box_pack_start(GTK_BOX(dialog_vbox1), entry_word, TRUE, TRUE, 0);
 
@@ -336,7 +339,7 @@ create_Configure(void)
 	gtk_window_set_title(GTK_WINDOW(Configure), _("Doc"));
 	gtk_window_set_type_hint(GTK_WINDOW(Configure), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-	dialog_vbox1 = GTK_DIALOG(Configure)->vbox;
+	dialog_vbox1 = gtk_dialog_get_content_area(GTK_DIALOG(Configure));
 	gtk_widget_show(dialog_vbox1);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
@@ -347,7 +350,7 @@ create_Configure(void)
 	gtk_widget_show(cbIntern);
 	gtk_box_pack_start(GTK_BOX(vbox1), cbIntern, FALSE, FALSE, 0);
 
-	comboboxType = gtk_combo_box_new_text();
+	comboboxType = gtk_combo_box_text_new();
 	gtk_widget_show(comboboxType);
 	gtk_box_pack_start(GTK_BOX(vbox1), comboboxType, FALSE, FALSE, 0);
 
@@ -383,19 +386,19 @@ create_Configure(void)
 	gtk_widget_show(label2);
 	gtk_box_pack_start(GTK_BOX(dialog_vbox1), label2, FALSE, FALSE, 0);
 
-	dialog_action_area1 = GTK_DIALOG(Configure)->action_area;
+	dialog_action_area1 = gtk_dialog_get_action_area(GTK_DIALOG(Configure));
 	gtk_widget_show(dialog_action_area1);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(dialog_action_area1), GTK_BUTTONBOX_END);
 
 	cancelbutton1 = gtk_button_new_from_stock("gtk-cancel");
 	gtk_widget_show(cancelbutton1);
 	gtk_dialog_add_action_widget(GTK_DIALOG(Configure), cancelbutton1, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS(cancelbutton1, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(cancelbutton1, TRUE);
 
 	okbutton1 = gtk_button_new_from_stock("gtk-ok");
 	gtk_widget_show(okbutton1);
 	gtk_dialog_add_action_widget(GTK_DIALOG(Configure), okbutton1, GTK_RESPONSE_OK);
-	GTK_WIDGET_SET_FLAGS(okbutton1, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(okbutton1, TRUE);
 
 	g_signal_connect_after((gpointer) comboboxType, "changed",
 			       G_CALLBACK(on_comboboxType_changed), NULL);
@@ -452,7 +455,7 @@ init_Configure(GtkWidget * dialog)
 
 	for (i = 0; i < geany->filetypes_array->len; i++)
 	{
-		gtk_combo_box_append_text(GTK_COMBO_BOX(cbTypes),
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(cbTypes),
 					  ((struct GeanyFiletype *) (filetypes[i]))->
 					  name);
 	}
